package com.sun.bigbrother.Trainer;

import org.kohsuke.jnt.*;
import com.enigmastation.classifier.*;
import com.enigmastation.classifier.impl.FisherClassifierImpl;

import java.io.*;

import java.util.logging.Logger;
import java.util.logging.Level;
import java.util.List;



public class TrainerMain {
    public static void main(String[] args) throws Exception {
        if (args.length < 2) {
             System.exit(usage());
        }

        FisherClassifierImpl fc = new FisherClassifierImpl();
        JNIssueTracker jni = getIssueTracker();
        train(jni, fc, new File(args[1]));
        writeObject(args[0], fc);
    }

    private static void writeObject(String filename, FisherClassifier fc) throws IOException {
        ObjectOutputStream out = null;
        try {
            out = new ObjectOutputStream(new FileOutputStream(filename));
            out.writeObject(fc);
        } finally {
            if (out != null)
                out.close();
        }
    }

    private static void train(JNIssueTracker jni, Trainer t, File dir) throws ProcessingException {
        for (File f : dir.listFiles()) {
            String n = f.getName();
            int id = Integer.parseInt(n.substring(0, 5));
            try {
                JNIssue i = jni.load(id, new FileInputStream(f));
                List<JNIssue.Description> list = i.getDescriptions();
                t.train(i.getShortDescription(), i.getSubComponent());
                t.train(list.get(0).getText(), i.getSubComponent());
            } catch (FileNotFoundException ex) {
                Logger.getLogger(TrainerMain.class.getName()).log(Level.SEVERE, null, ex);
            }
        }
    }

    private static JNIssueTracker getIssueTracker() throws ProcessingException {
        JavaNet jn = JavaNet.connect();
        JNProject gf = jn.getProject("glassfish");
        return gf.getIssueTracker();
    }

    private static int usage() {
        System.out.println("usage : java TrainerMain trainer-file-name trainer-inputdata-directory");
        System.out.println("example : java TrainerMain trainer.ser /Users/nachi/Bayes/data/");
        return 1;
    }
}
